<?php
/**
* Payamresan PHP API
*
* @package     Payamresan
* @copyright   Payamresan 2018
* @license     MIT
* @link        https://www.payam-resan.com
* @version     1.0.1
*/


if ($_GET['page'] ==('digits_settings')){
	wp_enqueue_script('payamresan-gateway-script', plugins_url('digits/gateways/payamresan/payamresan.js'), array(), null, 'all');
	wp_localize_script('payamresan-gateway-script', 'payamresandata', array('cssUrl' => plugins_url('digits/gateways/payamresan/')));
}

/**
* Main Payamresan API Class
* 
* @package  Payamresan
*/
class digits_payamresan {

  /*
  * Version of this class
  */
  private $Mversion = '1.0.1';

  /** 
  * Payamresan SMS API Username
  * 
  * @var string
  */
  private $username;
  
  /** 
  * Payamresan SMS API Password
  * 
  * @var string
  */
  private $Password;


  /**
  * From line used on text messages
  *
  * @var string (11 characters or 12 numbers)
  */
  private $sender;


  /**
  * Enables various logging of messages when true.
  *
  * @var bool
  */
  public $log;

  /**
  * What Payamresan should do if you send an invalid character
  *
  * Possible values:
  *      'error'     - Return an error (Messasge is not sent)
  *      'remove'    - Remove the invalid character(s)
  *      'replace'   - Replace invalid characters where possible, remove others 
  */
  public $invalid_char_action;

  /**
  * Create a new instance of the Clockwork wrapper
  *
  * @param   string  key         Your Clockwork API Key
  * @param   array   options     Optional parameters for sending SMS
  */
  public function __construct($arg ,array $options = array()) {
    if (empty($arg)) {
      error_log("Username and Password and Sender can't be blank");
    } else {
      $this->username = $arg['username'];
      $this->password = $arg['password'];
      $this->sender = $arg['sender'];
    }
    $this->invalid_char_action  = (array_key_exists('invalid_char_action', $options)) ? $options['invalid_char_action'] : null;
    $this->log                  = (array_key_exists('log', $options)) ? $options['log'] : false;
  }

  /**
  * Send some text messages
  * @author  Hadi Mollaei
  */
  public function send(array $sms) {
    if (!is_array($sms)) {
      error_log("sms parameter must be an array");
    }
	$client = new SoapClient('http://sms-webservice.ir/v1/v1.asmx?WSDL');
	$sendsms_parameters = array(
		'Username' => $this->username,
		'PassWord' => $this->password,
		'SenderNumber' => $this->sender,
		'RecipientNumbers' => array($sms['to']),
		'MessageBodie' => $sms['message'],
		'Type' => 1,
		'AllowedDelay' => 0,
	);
	$res = $client->SendMessage($sendsms_parameters);
	$status = $res->SendMessageResult->long;
	
	if ($status > 0) {
		if($this->log) error_log("payamresan : SMS sent json query:".json_encode(array('message'=>$sms['message'],'to'=>$sms['to'],'result'=>$status)));
		return array('success'=>true);
	} else {
		if($this->log) error_log("payamresan : SMS failed json query:".json_encode(array('message'=>$sms['message'],'to'=>$sms['to'],'error'=>$status ? $status : 'Unknow Error.')));
		return array('success'=>false);
	}
  }
}